@@ -60,7 +60,7 @@ new LambdaToSecretsmanager(scope: Construct, id: string, props: LambdaToSecretsm
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.|
+|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.|
 |lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
 |secretProps?|[`secretsmanager.SecretProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-secretsmanager.SecretProps.html)|Optional user provided props to override the default props for Secrets Manager|
 |existingSecretObj?|[`secretsmanager.Secret`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-secretsmanager.Secret.html)|Existing instance of Secrets Manager Secret object, If this is set then the secretProps is ignored|
@@ -157,8 +157,8 @@ class LambdaToSecretsmanager(
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
-        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
-        :param existing_secret_obj: Existing instance of Secret object, if this is set then secretProps is ignored. Default: - Default props are used
+        :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
+        :param existing_secret_obj: Existing instance of Secret object, providing both this and secretProps will cause an error. Default: - Default props are used
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param grant_write_access: Optional secret permissions to grant to the Lambda function. One of the following may be specified: "Read" or "ReadWrite". Default: - Read only acess is given to the Lambda function if no value is specified.
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
@@ -230,8 +230,8 @@ class LambdaToSecretsmanagerProps:
     ) -> None:
         '''
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
-        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
-        :param existing_secret_obj: Existing instance of Secret object, if this is set then secretProps is ignored. Default: - Default props are used
+        :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
+        :param existing_secret_obj: Existing instance of Secret object, providing both this and secretProps will cause an error. Default: - Default props are used
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param grant_write_access: Optional secret permissions to grant to the Lambda function. One of the following may be specified: "Read" or "ReadWrite". Default: - Read only acess is given to the Lambda function if no value is specified.
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
@@ -278,7 +278,7 @@ class LambdaToSecretsmanagerProps:
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        '''Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
+        '''Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error.
 
         :default: - None
         '''
@@ -287,7 +287,7 @@ class LambdaToSecretsmanagerProps:
 
     @builtins.property
     def existing_secret_obj(self) -> typing.Optional[aws_cdk.aws_secretsmanager.Secret]:
-        '''Existing instance of Secret object, if this is set then secretProps is ignored.
+        '''Existing instance of Secret object, providing both this and secretProps will cause an error.
 
         :default: - Default props are used
         '''
